pub struct BodyRange<T> { /* private fields */ }Expand description
A container for the payload slice and the optional Content-Range header.
The header is None only if the body was not sliced.
If the axum feature is enabled this struct also implements IntoResponse.
Implementations