pub struct ContentRange { /* private fields */ }Expand description
A container for the payload range and the optional Content-Range header.
The header is None only if the body was not sliced.
Implementations
Sourceimpl ContentRange
impl ContentRange